import os

class aReport:
	"""this is a class module to help automatically generate HTML pages for either reporting or just content disposition - it makes use of _empty.htm file in output subfolder as blank template by default"""
	sTemplateFile = ""
	sContent = "<html>\n<head>\n<title>#title#</title>\n</head>\n<body>\n<h2>#title#</h2>\n#body#\n</body>\n</html>\n"
	dContent = {}
	lContentKeys = []
	sTitle = ""
	
	def __init__(self, sTitle, sTemplate="output/_empty.htm"):
		self.sTitle = sTitle
		self.sTemplateFile = sTemplate
		if os.path.exists(self.sTemplateFile):
			fIn = open(self.sTemplateFile, "r")
			self.sContent = fIn.read()
			fIn.close()
		
	#end of __init__
	
	def stripContent(self, sIn):
		sOut = sIn.replace(chr(34), "&quot;")
		sOut = sOut.replace(chr(39), "&#39;")
		sOut = sOut.replace("<", "&lt;").replace(">", "&gt;")
		return sOut
	#end of stripContent
	
	def addTextBlock(self, sHeading = "", sBody = "", sAlignment="left", sClass=""):
		"""add paragraph to content - sHeading renders as bold line above sBody, sAlignment sets align attribute, and sClass can be assigned to paragraph to apply style sheeting class to it"""
		self.lContentKeys.append(sHeading)
		self.dContent[sHeading] = "<p align='" + sAlignment + "' class='" + sClass + "'><b>" + self.stripContent(sHeading) + "</b><br />" + self.stripContent(sBody) + "</p>\n"
	#end of addTextBlock
	
	def addTable(self, sTitle, sHeading = "", lHeaders = [], lContent = [], sTHStyle="", sTRStyle="", sTDStyle="", sWidth=""):
		"""add table element to content - sTitle is used to identify element, and gets inserted in table title attribute, lHeaders - list of TH content items, lContent list of column data each in a list item per row"""
		global spk
		sOut = ""
		if sHeading != "":
			sOut += "<h4>" + sHeading + "</h4>\n"
		sOut += "<table title='" + self.stripContent(sTitle) + "'"
		if sWidth != "":
			sOut += " width='" + self.stripContent(sWidth) + "'"
		sOut += ">\n"
		if len(lHeaders) > 0:
			sOut += "<tr style='" + self.stripContent(sTHStyle) + "'>\n"
			for th in lHeaders:
				sOut += "<th>" + self.stripContent(th) + "</th>"
			sOut += "</tr>\n"
		sColumns = str(len(lContent[0]))
		for tr in lContent:
			if len(tr) == 1:
				sOut += "<tr style='" + self.stripContent(sTRStyle) + "'>\n"
				sOut += "<td style='" + self.stripContent(sTDStyle) + "' colspan='" + sColumns + "'>" + self.stripContent(tr[0]) + "</td>"
				sOut += "</tr>\n"
			else:
				sOut += "<tr style='" + self.stripContent(sTRStyle) + "'>\n"
				for td in tr:
					sOut += "<td style='" + self.stripContent(sTDStyle) + "'>" + self.stripContent(td) + "</td>"
				sOut += "</tr>\n"
		sOut += "</table>\n"
		self.lContentKeys.append(sTitle)
		self.dContent[sTitle] = sOut
	#end of addTable

	def mergeContent(self):
		global spk
		sOut = self.sContent
		sOut = sOut.replace("#title#", self.stripContent(self.sTitle))
		sBody = ""
		for eachK in self.lContentKeys:
			sBody += self.dContent[eachK] + "\n"
		return sOut.replace("#body#", sBody)
	#end of mergeContent

#end of aReport class
